pub struct Deck {
pub name: String,
pub card_paths: Vec<String>,
pub interval_coefficients: IntervalCoefficients,
pub factor_mastered_threshold: Option<f64>,
pub interval_mastered_threshold: Option<f64>,
pub factor_forgotten_threshold: Option<f64>,
}Fields
name: Stringcard_paths: Vec<String>interval_coefficients: IntervalCoefficientsfactor_mastered_threshold: Option<f64>Override for the global factor threshold above which a card is “mastered”.
interval_mastered_threshold: Option<f64>Override for the global interval threshold (days) above which a card is “mastered”.
factor_forgotten_threshold: Option<f64>Override for the global factor threshold below which a card is “forgotten”.
Implementations
Sourceimpl Deck
impl Deck
pub fn new( name: &str, card_paths: Vec<&str>, interval_coefficients: IntervalCoefficients, ) -> Self
pub fn with_interval_coefficients( self, interval_coefficients: IntervalCoefficients, ) -> Self